@@ -1,9 +1,10 @@
 from enum import Enum
 from typing import List, Optional, Union
-from watchmen_utilities import ArrayHelper
+
 from pydantic import BaseModel
 
 from watchmen_model.common import DataModel, DataSourceId, OptimisticLock, TenantBasedTuple
+from watchmen_utilities import ArrayHelper
 
 
 class DataSourceParam(DataModel, BaseModel):
@@ -15,8 +16,10 @@ class DataSourceType(str, Enum):
 	MYSQL = 'mysql',
 	ORACLE = 'oracle',
 	MONGODB = 'mongodb',
-	MSSQL = 'mssql'
-	POSTGRESQL = 'postgresql'
+	MSSQL = 'mssql',
+	POSTGRESQL = 'postgresql',
+	OSS = 'oss',
+	S3 = 's3'
 
 
 def construct_param(param: Optional[Union[dict, DataSourceParam]]) -> Optional[DataSourceParam]:
@@ -51,4 +54,4 @@ class DataSource(TenantBasedTuple, OptimisticLock, BaseModel):
 		if name == 'params':
 			super().__setattr__(name, construct_params(value))
 		else:
-			super().__setattr__(name, value)
\ No newline at end of file
+			super().__setattr__(name, value)
